@@ -1,5 +1,5 @@
 from __future__ import print_function, unicode_literals
-import json, itertools, time
+import os, json, itertools, time
 from binascii import hexlify
 import mock
 from twisted.trial import unittest
@@ -11,7 +11,7 @@ from twisted.web import client
 from autobahn.twisted import websocket
 from .. import __version__
 from .common import ServerBase
-from ..server import rendezvous, transit_server
+from ..server import server, rendezvous, transit_server
 from ..server.rendezvous import Usage, SidedMessage
 from ..server.database import get_db
 
@@ -1043,6 +1043,29 @@ class Summary(unittest.TestCase):
         row = db.execute("SELECT * FROM `mailbox_usage`").fetchone()
         self.assertEqual(row["started"], 20)
 
+class DumpStats(unittest.TestCase):
+    def test_nostats(self):
+        rs = server.RelayServer(str("tcp:0"), str("tcp:0"), None)
+        # with no ._stats_file, this should do nothing
+        rs.dump_stats(1, 1)
+
+    def test_empty(self):
+        basedir = self.mktemp()
+        os.mkdir(basedir)
+        fn = os.path.join(basedir, "stats.json")
+        rs = server.RelayServer(str("tcp:0"), str("tcp:0"), None,
+                                stats_file=fn)
+        now = 1234
+        validity = 500
+        rs.dump_stats(now, validity)
+        with open(fn, "rb") as f:
+            data_bytes = f.read()
+        data = json.loads(data_bytes.decode("utf-8"))
+        self.assertEqual(data["created"], now)
+        self.assertEqual(data["valid_until"], now+validity)
+        self.assertEqual(data["rendezvous"]["all_time"]["mailboxes_total"], 0)
+        self.assertEqual(data["transit"]["all_time"]["total"], 0)
+
 
 class Accumulator(protocol.Protocol):
     def __init__(self):
@@ -1136,6 +1159,26 @@ class Transit(ServerBase, unittest.TestCase):
 
         a1.transport.loseConnection()
 
+    @defer.inlineCallbacks
+    def test_binary_handshake(self):
+        ep = clientFromString(reactor, self.transit)
+        a1 = yield connectProtocol(ep, Accumulator())
+
+        binary_bad_handshake = b"\x00\x01\xe0\x0f\n\xff"
+        # the embedded \n makes the server trigger early, before the full
+        # expected handshake length has arrived. A non-wormhole client
+        # writing non-ascii junk to the transit port used to trigger a
+        # UnicodeDecodeError when it tried to coerce the incoming handshake
+        # to unicode, due to the ("\n" in buf) check. This was fixed to use
+        # (b"\n" in buf). This exercises the old failure.
+        a1.transport.write(binary_bad_handshake)
+
+        exp = b"bad handshake\n"
+        yield a1.waitForBytes(len(exp))
+        self.assertEqual(a1.data, exp)
+
+        a1.transport.loseConnection()
+
     @defer.inlineCallbacks
     def test_impatience(self):
         ep = clientFromString(reactor, self.transit)
